pub struct Column {
pub name: String,
pub type_: String,
}Expand description
Contains information about a column that stores your data.
Fields
name: StringThe name of the column.
type_: StringThe type of data. For more information about the supported data types, see Common data types in the AWS Glue Developer Guide.